'---------------------------------------------------------------------
' ras_init.vbs
'
' helper application to initiate ras connections and alter default
' routes so that only ras-destinated traffic routes through it's
' gateway and everything else passes through the local default network gateway
'
' Released under the terms of the GNU GPL Version 2.
'---------------------------------------------------------------------
' r0.1 2006/06/13 Gianpaolo Del Matto <codegeek@phunsites.net>
' - initial release
' - tested on Windows 2000/XP
' - searches through all interfaces and looks for the expected RAS subnet address
' - removes RAS default route and replace it by your local default route
' - optionally set up host/network routes for routing through RAS
'
' r0.2 2006/06/16 Gianpaolo Del Matto <codegeek@phunsites.net>
' - add support for interactive/non-interactive mode
'---------------------------------------------------------------------



'---------------------------------------------------------------------
' connection settings, change as required
'---------------------------------------------------------------------

RAS_Subnet	= "192.168.254"			' 3 octets as base from expected IP Range
RAS_Name	= "CONNECTION"			' change to your RAS VPN connection name
RAS_User	= "USERNAME"			' change to your RAS VPN user name
RAS_Pass	= "PASSWORD"			' change to your RAS VPN password

Dim RAS_Routes					' add your RAS host/net routes below
RAS_Routes = Array( _
	"192.168.0.0 MASK 255.255.240.0", _
	"192.168.254.0 MASK 255.255.255.0", _
	"192.168.16.0 MASK 255.255.254.0" )

'SearchString	= "IP Address"			' output search string, might need to be localized
SearchString	= "IP-Adresse"			' use this one on german Windows 2000/XP

NetGW_Local	= "1.2.3.4"			' IP address of your local network gateway ("default route")


'---------------------------------------------------------------------
' runtime init, usually not to be changed
'---------------------------------------------------------------------

Const ForReading   = 1				' for use with file system object
Const ForWriting   = 2				' for use with file system object
Const ForAppending = 8				' for use with file system object

set o_FileSys	= CreateObject("Scripting.FileSystemObject")	' file system object
set o_Shell	= CreateObject("WScript.Shell")			' shell object
Set o_Env	= o_Shell.Environment("Process")		' system environment object

TempFile	= o_Env("TEMP") & "\vpn_init.tmp"		' a temporary file, usually not to be changed

SetRoutes	= false						' assume to not change routes by default (don't change!)


if (InStr(wscript.FullName,"cscript") > 0) then			' are we running in interactive mode?
	bInteractive = false
else
	bInteractive = true
end If 


'---------------------------------------------------------------------
' initiate connection
'---------------------------------------------------------------------


if not bInteractive then wscript.echo "Initiating RAS connection ..." & vbCRLF
o_Shell.Run "%comspec% /c rasdial.exe " & RAS_Name & " " & RAS_User & " " & RAS_Pass,2,true 


'---------------------------------------------------------------------
' Get IP address data
'---------------------------------------------------------------------

if not bInteractive then wscript.echo "Retrieving RAS gateway IP address ..."
o_Shell.Run "%comspec% /c ipconfig.exe > " & TempFile,2,true
set o_TempFile = o_FileSys.OpenTextFile(TempFile, ForReading)

do while o_TempFile.AtEndOfStream <> true		' read all lines from temporary file
	s_output = o_TempFile.ReadLine

	If instr(s_output,SearchString) <> 0 then
		i_Pos = Instr(21,s_output,":")
		s_IPAddress = Mid(s_output,i_Pos+2)

		If Trim(Left(s_IPAddress,Len(RAS_Subnet))) = RAS_Subnet then
			NetGW_RAS = s_IPAddress
			if not bInteractive then wscript.echo "found: " & NetGW_RAS
			setRoutes = true
			exit do
		End If
	end if	
loop

if setRoutes then
	if not bInteractive then wscript.echo "RAS connection established, altering routes accordingly ..."

	if not bInteractive then wscript.echo "re-instate network default route..."
	o_Shell.run "%comspec% /c route add 0.0.0.0 MASK 0.0.0.0 "& NetGW_Local, 0, true

	if not bInteractive then wscript.echo "removing RAS default route..."
	o_Shell.run "%comspec% /c route delete 0.0.0.0 MASK 0.0.0.0 "& NetGW_RAS, 0, true

	if ubound(RAS_Routes) > 0 then
		if not bInteractive then wscript.echo "setting up RAS host/network routes..."
		for i=0 to ubound(RAs_Routes)
			if not bInteractive then wscript.echo RAS_Routes(i)
			o_Shell.run "%comspec% /c route add " & RAS_Routes(i) &" "& NetGW_RAS, 0, true
		next
	end if
else
	if not bInteractive then wscript.echo "No RAS connection was found, existing routes will not be changed!"
end if


'---------------------------------------------------------------------
' cleanup
'---------------------------------------------------------------------

o_TempFile.Close
o_FileSys.DeleteFile TempFile,true

set o_TempFile	= nothing
set o_FileSys	= nothing
set o_Shell	= nothing
set o_Env	= nothing